@@ -9,6 +9,7 @@ try:
     PDFGETX_AVAILABLE = True
     del diffpy.pdfgetx
 except ImportError:
+    print("Warning: diffpy.pdfgetx is not installed. Some functionalities may not be available.")
     PDFGETX_AVAILABLE = False
 
 COMMANDS = {
@@ -23,12 +24,15 @@ SERVERS = {}
 if PDFGETX_AVAILABLE:
     import pdfstream.transformation.cli
 
+    COMMANDS.update({'transform': pdfstream.transformation.cli.transform})
+
     import pdfstream.servers.xpd_server as xpd_server
     import pdfstream.servers.lsq_server as lsq_server
+    import pdfstream.servers.xpdvis_server as xpdvis_server
 
-    COMMANDS.update({'transform': pdfstream.transformation.cli.transform})
     SERVERS.update({ServerNames.xpd: xpd_server.make_and_run})
     SERVERS.update({ServerNames.lsq: lsq_server.make_and_run})
+    SERVERS.update({ServerNames.xpdvis: xpdvis_server.make_and_run})
 
 
 def main():
