@@ -60,6 +60,23 @@ def test_XPDRouter(db_with_img_and_bg_img, tmpdir):
     assert len(list(an_db)) > 0
 
 
+def test_XPDRouter_no_calib(db_with_dark_bg_no_calib, tmpdir):
+    raw_db = db_with_dark_bg_no_calib
+    config = mod.XPDConfig()
+    config.read(fn)
+    config.tiff_base = str(tmpdir)
+    config.calib_base = str(tmpdir)
+    an_db = config.an_db
+    cb = mod.XPDRouter(config)
+    for name, doc in raw_db[-1].canonical(fill="yes", strict_order=True):
+        cb(name, doc)
+    tiff_base = Path(config.tiff_base)
+    assert len(list(tiff_base.rglob("*.tiff"))) == 3
+    assert len(list(tiff_base.rglob("*.json"))) == 1
+    assert len(list(tiff_base.rglob("*.csv"))) == 2
+    assert len(list(an_db)) > 0
+
+
 def test_XPDRouter_with_xpdan_exporter(db_with_img_and_bg_img, tmpdir):
     raw_db = db_with_img_and_bg_img
     config = mod.XPDConfig()
